@@ -6,7 +6,7 @@ from extract_msg import __doc__, utils
 from extract_msg.compat import os_ as os
 from extract_msg.message import Message
 
-if __name__ == '__main__':
+def main():
     # Setup logging to stdout, indicate running from cli
     CLI_LOGGING = 'extract_msg_cli'
 
@@ -38,14 +38,21 @@ if __name__ == '__main__':
             fil.write(json.dumps(val_results))
         utils.get_input('Press enter to exit...')
     else:
-        utils.setup_logging(args.config_path, level, args.log, args.file_logging)
+        if not args.dump_stdout:
+            utils.setup_logging(args.config_path, level, args.log, args.file_logging)
         for x in args.msgs:
             try:
                 with Message(x[0]) as msg:
                     # Right here we should still be in the path in currentdir
-                    os.chdir(out)
-                    msg.save(toJson = args.json, useFileName = args.use_filename, ContentId = args.cid)#, html = args.html, rtf = args.html)
+                    if args.dump_stdout:
+                        print(msg.body)
+                    else:
+                        os.chdir(out)
+                        msg.save(toJson = args.json, useFileName = args.use_filename, ContentId = args.cid)#, html = args.html, rtf = args.html)
             except Exception as e:
                 print("Error with file '" + x[0] + "': " +
                       traceback.format_exc())
             os.chdir(currentdir)
+
+if __name__ == '__main__':
+    main()
